<?php

class ActionSquadro {
    private $plateau;

    public function __construct(PlateauSquadro $plateau) {
        $this->plateau = $plateau;
    }

    public function testJouablePiece($x, $y) {
        $piece = $this->plateau->getPiece($x, $y);
        if ($piece->getCouleur() === PieceSquadro::VIDE) {
            return false;
        }
        list($newX, $newY) = $this->plateau->getCoordDestination($x, $y);
        return $this->plateau->getPiece($newX, $newY)->getCouleur() === PieceSquadro::VIDE;
    }

    // La méthode ne vérifie pas si la pièce a atteint sa case de retournement avant de tenter de l'inverser.
    // ça peut des erreurs si la pièce n'est pas dans une position valide.
    // Solution : Ajouter une vérification pour s'assurer que la pièce est dans une position valide avant de l'inverser.
    public function jouePiece($x, $y) {
        if (!$this->testJouablePiece($x, $y)) {
            return;
        }
        $piece = $this->plateau->getPiece($x, $y);
        list($newX, $newY) = $this->plateau->getCoordDestination($x, $y);
        $this->plateau->setPiece($piece, $newX, $newY);
        $this->plateau->setPiece(PieceSquadro::initVide(), $x, $y);
        if ($this->plateau->getPiece($newX, $newY)->getCouleur() === PieceSquadro::BLANC && $newY === 6) {
            $piece->inverseDirection();
        } elseif ($this->plateau->getPiece($newX, $newY)->getCouleur() === PieceSquadro::NOIR && $newX === 0) {
            $piece->inverseDirection();
        }
    }

    // La méthode ne vérifie pas si la pièce est dans une position valide avant de la renvoyer à sa case de départ.
    // Solution : Ajouter une vérification pour s'assurer que la pièce est dans une position valide avant de la renvoyer à sa case de départ.
    public function reculePiece($x, $y) {
        $piece = $this->plateau->getPiece($x, $y);
        if ($piece->getCouleur() === PieceSquadro::BLANC) {
            $this->plateau->setPiece($piece, $x, 0);
        } else {
            $this->plateau->setPiece($piece, 6, $y);
        }
    }

    // La méthode ne vérifie pas si la pièce est dans une position valide avant de la retirer du plateau.
    // Solution : Ajouter une vérification pour s'assurer que la pièce est dans une position valide avant de la retirer.
    public function sortPiece($couleur, $rang) {
        foreach ($this->plateau->getPlateau() as $i => $row) {
            foreach ($row as $j => $piece) {
                if ($piece->getCouleur() === $couleur && $piece->getDirection() === PieceSquadro::NORD) {
                    $this->plateau->setPiece(PieceSquadro::initVide(), $i, $j);
                    return;
                }
            }
        }
    }

    // La méthode ne vérifie pas si le plateau est valide avant de tenter de compter les pièces.
    // Solution : Ajouter une vérification pour s'assurer que le plateau est valide avant de compter les pièces.
    public function remporteVictoire($couleur) {
        $count = 0;
        foreach ($this->plateau->getPlateau() as $row) {
            foreach ($row as $piece) {
                if ($piece->getCouleur() === $couleur && $piece->getDirection() === PieceSquadro::NORD) {
                    $count++;
                }
            }
        }
        return $count >= 4;
    }
}
?>